@@ -88,7 +88,7 @@ class LeCrapaud:
         """
         return ExperimentEngine(id=id, **kwargs)
 
-    def get_last_experiement_by_name(self, name: str, **kwargs) -> "ExperimentEngine":
+    def get_last_experiment_by_name(self, name: str, **kwargs) -> "ExperimentEngine":
         """Retrieve the last experiment by name."""
         return ExperimentEngine(id=Experiment.get_last_by_name(name).id, **kwargs)
 
@@ -100,6 +100,65 @@ class LeCrapaud:
             id=Experiment.get_best_by_score(name=name, metric=metric).id, **kwargs
         )
 
+    def compare_experiment_scores(self, name: str):
+        """Compare scores of experiments with matching names.
+        
+        Args:
+            name (str): Name or partial name of experiments to compare
+            
+        Returns:
+            dict: Dictionary containing experiment names as keys and their scores as values
+        """
+        from lecrapaud.db import SessionLocal
+        from sqlalchemy.orm import joinedload
+        
+        db = SessionLocal()
+        try:
+            # Get all experiments with the given name pattern
+            experiments = (
+                db.query(Experiment)
+                .options(joinedload(Experiment.model_selections)
+                        .joinedload(ModelSelection.scores))
+                .filter(Experiment.name.ilike(f"%{name}%"))
+                .all()
+            )
+            
+            if not experiments:
+                return {"error": f"No experiments found with name containing '{name}'"}
+                
+            comparison = {}
+            
+            for exp in experiments:
+                scores = {
+                    "rmse": exp.avg_rmse,
+                    "logloss": exp.avg_logloss,
+                    "accuracy": None,
+                    "f1": None,
+                    "roc_auc": None
+                }
+                
+                # Get classification metrics from the first model selection with scores
+                for model_sel in exp.model_selections:
+                    if model_sel.scores:
+                        for score in model_sel.scores:
+                            if score.type == 'validation':  # Use validation scores
+                                if score.accuracy is not None:
+                                    scores["accuracy"] = score.accuracy
+                                if score.f1 is not None:
+                                    scores["f1"] = score.f1
+                                if score.roc_auc is not None:
+                                    scores["roc_auc"] = score.roc_auc
+                                break
+                
+                comparison[exp.name] = scores
+                
+            return comparison
+            
+        except Exception as e:
+            return {"error": f"Error comparing experiment scores: {str(e)}"}
+        finally:
+            db.close()
+    
     def list_experiments(
         self, name: str = None, limit: int = 1000
     ) -> list["ExperimentEngine"]:
@@ -131,7 +190,6 @@ class ExperimentEngine:
             experiment_dir = f"{tmp_dir}/{self.experiment.name}"
             preprocessing_dir = f"{experiment_dir}/preprocessing"
             data_dir = f"{experiment_dir}/data"
-            os.makedirs(experiment_dir, exist_ok=True)
             os.makedirs(preprocessing_dir, exist_ok=True)
             os.makedirs(data_dir, exist_ok=True)
         else:
@@ -488,10 +546,10 @@ class ExperimentEngine:
             if threshold is not None:
                 tmp_pred = prediction[["TARGET", "PRED", class_label]].copy()
                 tmp_pred.rename(columns={class_label: 1}, inplace=True)
-                logger.info(f"Class {class_label}:")
+                print(f"Class {class_label}:")
                 plot_threshold(tmp_pred, threshold, precision, recall)
             else:
-                logger.info(f"No threshold found for class {class_label}")
+                print(f"No threshold found for class {class_label}")
 
     def get_best_params(self, target_number: int = None) -> dict:
         """
