@@ -241,7 +241,7 @@ class Experiment(Base):
             # This ensures we're comparing apples to apples by normalizing the scores
             experiments = db.query(cls).filter(cls.name.ilike(f"%{name}%")).all()
             if not experiments:
-                return None
+                raise ValueError(f"No experiments found with the given name: {name}")
 
             # Get all scores
             rmse_scores = [e.avg_rmse for e in experiments if e.avg_rmse is not None]
@@ -250,7 +250,9 @@ class Experiment(Base):
             ]
 
             if not rmse_scores or not logloss_scores:
-                return None
+                raise ValueError(
+                    "No experiments found with both RMSE and LogLoss scores. Maybe try with only one metric."
+                )
 
             # Normalize scores (subtract min and divide by range)
             min_rmse = min(rmse_scores)
@@ -277,18 +279,107 @@ class Experiment(Base):
 
             return experiment_scores[0][0] if experiment_scores else None
 
-        # For single metric case (rmse or logloss)
-        score_property = cls.avg_rmse if metric == "rmse" else cls.avg_logloss
+        elif metric == "rmse" or metric == "logloss":
+            # For single metric case (rmse or logloss)
+            # Need to get all experiments first to evaluate instance properties
+            experiments = db.query(cls).filter(cls.name.ilike(f"%{name}%")).all()
 
-        return (
-            db.query(cls)
-            .filter(
-                cls.name.ilike(f"%{name}%"), score_property.isnot(None)
-            )  # Only consider experiments with scores
-            .order_by(score_property)
-            .first()
+            if not experiments:
+                return None
+
+            # Filter out experiments without scores and sort by the selected metric
+            filtered_experiments = []
+            for exp in experiments:
+                score = exp.avg_rmse if metric == "rmse" else exp.avg_logloss
+                if score is not None:
+                    filtered_experiments.append((exp, score))
+
+            if not filtered_experiments:
+                return None
+
+            # Sort by score (ascending since lower is better)
+            filtered_experiments.sort(key=lambda x: x[1])
+            return filtered_experiments[0][0]
+        else:
+            raise ValueError("Invalid metric. Must be 'rmse', 'logloss', or 'both'.")
+
+    def best_score(self, target_number: int) -> dict:
+        """
+        Returns the scores for the best model of the specified target.
+        
+        Args:
+            target_number (int): The target number to get scores for
+            
+        Returns:
+            dict: A dictionary containing the experiment name, target number, and the best model's scores
+        """
+        # Find the target
+        target_name = f"TARGET_{target_number}"
+        target = next((t for t in self.targets if t.name == target_name), None)
+        
+        if not target:
+            return {
+                'experiment_name': self.name,
+                'target_number': target_number,
+                'error': f'Target {target_name} not found in this experiment',
+                'scores': {}
+            }
+        
+        # Find the best model selection for this target
+        best_model_selection = next(
+            (ms for ms in self.model_selections if ms.target_id == target.id),
+            None
         )
-
+        
+        if not best_model_selection or not best_model_selection.model_trainings:
+            return {
+                'experiment_name': self.name,
+                'target_number': target_number,
+                'error': 'No model found for this target',
+                'scores': {}
+            }
+        
+        # Get the best model training (assuming the first one is the best)
+        best_training = best_model_selection.model_trainings[0]
+        
+        # Get the validation score for this training
+        validation_scores = [s for s in best_training.score if s.type == 'validation']
+        
+        if not validation_scores:
+            return {
+                'experiment_name': self.name,
+                'target_number': target_number,
+                'error': 'No validation scores found for the best model',
+                'scores': {}
+            }
+        
+        # Get all available metrics from the first validation score
+        score = validation_scores[0]
+        available_metrics = [
+            'rmse', 'mae', 'r2', 'logloss', 'accuracy', 
+            'precision', 'recall', 'f1', 'roc_auc'
+        ]
+        
+        scores = {}
+        for metric in available_metrics:
+            value = getattr(score, metric, None)
+            if value is not None:
+                scores[metric] = value
+        
+        # Get the model info
+        model_info = {
+            'model_type': best_training.model.model_type if best_training.model else 'unknown',
+            'model_name': best_training.model.name if best_training.model else 'unknown',
+            'training_time_seconds': best_training.training_time
+        }
+        
+        return {
+            'experiment_name': self.name,
+            'target_number': target_number,
+            'model': model_info,
+            'scores': scores
+        }
+        
     def get_features(self, target_number: int):
         targets = [t for t in self.targets if t.name == f"TARGET_{target_number}"]
         if targets:
