@@ -13,6 +13,8 @@ from lecrapaud.config import DB_USER, DB_PASSWORD, DB_HOST, DB_PORT, DB_NAME, DB
 _engine = None
 _SessionLocal = None
 if DB_URI:
+    if "mysql://" in DB_URI and "pymysql://" not in DB_URI:
+        DB_URI = DB_URI.replace("mysql://", "mysql+pymysql://")
     DATABASE_URL = DB_URI
 elif DB_USER:
     DATABASE_URL = (
@@ -23,15 +25,13 @@ else:
 
 
 def init_db(uri: str = None):
-    global _engine, _SessionLocal, DATABASE_URL
+    global _engine, _SessionLocal, DATABASE_URL, DB_URI
     if uri:
+        if "mysql://" in uri and "pymysql://" not in uri:
+            uri = uri.replace("mysql://", "mysql+pymysql://")
         DATABASE_URL = uri
-    elif DB_USER:
-        DATABASE_URL = (
-            f"mysql+pymysql://{DB_USER}:{DB_PASSWORD}@{DB_HOST}:{DB_PORT}/{DB_NAME}"
-        )
-    elif DB_URI:
-        DATABASE_URL = DB_URI
+    elif DATABASE_URL:
+        pass
     else:
         raise ValueError(
             "No database configuration found, please set env variables "
