@@ -364,6 +364,12 @@ class PreprocessFeature:
 
         joblib.dump(pcas, f"{self.preprocessing_dir}/pcas.pkl")
 
+        # Save all features before encoding
+        joblib.dump(
+            list(train.columns),
+            f"{self.preprocessing_dir}/all_features_before_encoding.pkl",
+        )
+
         # Encoding
         train, transformer = self.encode_categorical_features(train)
         val, _ = self.encode_categorical_features(
@@ -382,7 +388,8 @@ class PreprocessFeature:
 
         # Save all features before selection
         joblib.dump(
-            train, f"{self.preprocessing_dir}/all_features_before_selection.pkl"
+            list(train.columns),
+            f"{self.preprocessing_dir}/all_features_before_selection.pkl",
         )
 
         return train, val, test
