@@ -5,11 +5,6 @@ from lecrapaud.jobs.tasks import app
 
 def schedule_tasks():
     schedule_tasks_list = [
-        {
-            "name": "task_send_daily_emails",
-            "task": "src.jobs.tasks.task_send_daily_emails",
-            "schedule": crontab(minute=00, hour=12),
-        },
         {
             "name": "task_training_experiment",
             "task": "src.jobs.tasks.task_training_experiment",
@@ -24,8 +19,7 @@ def schedule_tasks():
 
 def unschedule_tasks():
     unschedule_task_keys = [
-        "redbeat:task_send_daily_emails",
-        "redbeat:task_train_models",
+        "redbeat:task_training_experiment",
     ]
 
     for key in unschedule_task_keys:
