@@ -883,7 +883,7 @@ class ModelSelectionEngine:
                         model_best_params = json_dict[model_name]
                 except Exception:
                     raise FileNotFoundError(
-                        f"Could not find {model_name} in current data. Try to run an hyperoptimization by setting `perform_hyperopt` to true, pass `best_params`"
+                        f"Could not find {model_name} in current data. Try to run an hyperoptimization by setting `perform_hyperopt` to true, or pass `best_params`"
                     )
 
             # save best params
@@ -1133,6 +1133,27 @@ class ModelSelectionEngine:
 
         storage_path = f"{self.results_dir}/ray_results"
 
+        # Initialize Ray with the runtime environment
+        ray.init(
+            runtime_env={
+                "excludes": [
+                    ".git/**/*",
+                    "**/*.pyc",
+                    "**/__pycache__",
+                    "**/data/*",
+                    "**/notebooks/*",
+                    "**/tests/*",
+                    "**/docs/*",
+                    "**/.pytest_cache/*",
+                    "**/venv/*",
+                    "**/.venv/*",
+                    "**/build/*",
+                    "**/dist/*",
+                    "**/*.egg-info/*",
+                ]
+            }
+        )
+
         tuner = Tuner(
             trainable=with_parameters(
                 trainable,
@@ -1232,7 +1253,7 @@ class ModelSelectionEngine:
                 try:
                     with open(best_params_file, "r") as f:
                         target_params = json.load(f)
-                        all_best_params[target_number] = target_params
+                        all_best_params[int(target_number)] = target_params
                 except Exception as e:
                     logger.warning(
                         f"Error loading best params for {target_dir}: {str(e)}"
@@ -1571,20 +1592,104 @@ def plot_evaluation_for_classification(prediction: dict):
 
 
 def plot_confusion_matrix(y_true, y_pred):
-    unique_labels = np.unique(np.concatenate((y_true, y_pred)))
+    # Calculate confusion matrix
     cm = confusion_matrix(y_true, y_pred)
 
-    labels = np.sort(unique_labels)  # Sort labels based on numerical order
+    # Get unique, sorted class labels
+    labels = np.unique(np.concatenate((y_true, y_pred)))
+    labels = np.sort(labels)
 
-    plt.figure(figsize=(10, 7))
-    sns.heatmap(cm, annot=True, fmt="d", cmap="viridis")
-    plt.xlabel("Predicted", fontsize=12)
-    plt.ylabel("True", fontsize=12)
-    plt.title("Confusion Matrix", fontsize=14)
+    # Calculate class distribution
+    class_dist = np.bincount(y_true.astype(int))
+    class_dist_pct = class_dist / len(y_true) * 100
 
-    plt.xticks(ticks=np.arange(len(labels)), labels=labels, fontsize=10)
-    plt.yticks(ticks=np.arange(len(labels)), labels=labels, fontsize=10)
+    # Create figure with two subplots stacked vertically
+    fig = plt.figure(figsize=(10, 12))
 
+    # Subplot 1: Confusion Matrix
+    ax1 = plt.subplot(2, 1, 1)  # Changed to 2 rows, 1 column, first subplot
+
+    # Create a custom colormap (blue to white to red)
+    cmap = sns.diverging_palette(220, 10, as_cmap=True)
+
+    # Plot heatmap with better styling
+    sns.heatmap(
+        cm,
+        annot=True,
+        fmt="d",
+        cmap=cmap,
+        center=0,
+        linewidths=0.5,
+        linecolor="lightgray",
+        cbar_kws={"label": "Number of Samples"},
+        ax=ax1,
+    )
+
+    # Add title and labels with better styling
+    ax1.set_title("Confusion Matrix", fontsize=14, pad=20, weight="bold")
+    ax1.set_xlabel("Predicted Label", fontsize=12, labelpad=10)
+    ax1.set_ylabel("True Label", fontsize=12, labelpad=10)
+
+    # Set tick labels to be centered and more readable
+    ax1.set_xticks(np.arange(len(labels)) + 0.5)
+    ax1.set_yticks(np.arange(len(labels)) + 0.5)
+    ax1.set_xticklabels(labels, fontsize=10)
+    ax1.set_yticklabels(labels, fontsize=10, rotation=0)
+
+    # Add grid lines for better readability
+    ax1.set_xticks(np.arange(len(labels) + 1) - 0.5, minor=True)
+    ax1.set_yticks(np.arange(len(labels) + 1) - 0.5, minor=True)
+    ax1.grid(which="minor", color="w", linestyle="-", linewidth=2)
+    ax1.tick_params(which="minor", bottom=False, left=False)
+
+    # Subplot 2: Class Distribution
+    ax2 = plt.subplot(2, 1, 2)  # Changed to 2 rows, 1 column, second subplot
+
+    # Create a bar plot for class distribution
+    bars = ax2.bar(
+        labels.astype(str),
+        class_dist_pct,
+        color=sns.color_palette("viridis", len(labels)),
+    )
+
+    # Add percentage labels on top of bars
+    for bar in bars:
+        height = bar.get_height()
+        ax2.text(
+            bar.get_x() + bar.get_width() / 2.0,
+            height + 1,
+            f"{height:.1f}%",
+            ha="center",
+            va="bottom",
+            fontsize=10,
+        )
+
+    # Add title and labels
+    ax2.set_title("Class Distribution", fontsize=14, pad=20, weight="bold")
+    ax2.set_xlabel("Class", fontsize=12, labelpad=10)
+    ax2.set_ylabel("Percentage of Total Samples", fontsize=12, labelpad=10)
+    ax2.set_ylim(0, 100)
+    ax2.grid(axis="y", linestyle="--", alpha=0.7)
+
+    # Add total count annotation
+    total = len(y_true)
+    ax2.text(
+        0.5,
+        -0.15,  # Adjusted y-position for better spacing
+        f"Total samples: {total:,}",
+        transform=ax2.transAxes,
+        ha="center",
+        fontsize=10,
+        bbox=dict(
+            facecolor="white",
+            alpha=0.8,
+            edgecolor="lightgray",
+            boxstyle="round,pad=0.5",
+        ),
+    )
+
+    # Adjust layout to prevent overlap with more vertical space
+    plt.tight_layout(rect=[0, 0.03, 1, 0.98])
     plt.show()
 
 
@@ -1789,7 +1894,7 @@ def plot_threshold(prediction, threshold, precision, recall):
     per_predicted_positive = predicted_positive / len(y_pred_proba)
     per_predicted_negative = predicted_negative / len(y_pred_proba)
 
-    logger.info(
+    print(
         f"""Threshold: {threshold*100:.2f}
         Precision: {precision*100:.2f}
         Recall: {recall*100:.2f}
